@@ -1,10 +1,11 @@
 """Ats Reception entity"""
 
 from datetime import datetime
-from typing import Optional
 
 from pydantic import BaseModel, Field
 
+from layrz_sdk.constants import UTC
+
 
 class AtsReception(BaseModel):
   """AtsReception entity"""
@@ -14,12 +15,24 @@ class AtsReception(BaseModel):
     description='Volume bought in liters',
     default=0.0,
   )
-  real_volume: Optional[float] = Field(
+  real_volume: float | None = Field(
     description='Real volume in liters',
     default=None,
   )
 
   received_at: datetime = Field(
     description='Date and time when the reception was made',
-    default_factory=datetime.now,
+    default_factory=lambda: datetime.now(UTC),
+  )
+  fuel_type: str = Field(
+    description='Type of fuel used in the reception',
+    default='',
+  )
+  is_merged: bool = Field(
+    description='Indicates if the reception is merged with another',
+    default=False,
+  )
+  order_id: int | None = Field(
+    description='Order ID associated with the reception',
+    default=None,
   )
