@@ -1,15 +1,10 @@
 """Chart alignment"""
 
-import sys
-from enum import Enum
-
-if sys.version_info >= (3, 11):
-  from typing import Self
-else:
-  from typing_extensions import Self
+from enum import StrEnum
+from typing import Self
 
 
-class ChartColor(str, Enum):
+class ChartColor(StrEnum):
   """Chart color list, ideal to use to colorize the series"""
 
   RED = '#F44336'
