@@ -1,15 +1,9 @@
 """HTML chart"""
 
-import sys
-from typing import Any, Dict
+from typing import Any, Dict, Self
 
 from pydantic import BaseModel, Field
 
-if sys.version_info >= (3, 11):
-  from typing import Self
-else:
-  from typing_extensions import Self
-
 
 class HTMLChart(BaseModel):
   """HTML chart configuration"""
