@@ -1,7 +1,6 @@
 """Number chart"""
 
-import sys
-from typing import Any
+from typing import Any, Self
 
 from pydantic import BaseModel, Field
 
@@ -9,11 +8,6 @@ from .chart_render_technology import ChartRenderTechnology
 from .table_header import TableHeader
 from .table_row import TableRow
 
-if sys.version_info >= (3, 11):
-  from typing import Self
-else:
-  from typing_extensions import Self
-
 
 class TableChart(BaseModel):
   """Table chart configuration"""
