@@ -23,7 +23,7 @@ class Trigger(BaseModel):
     },
   }
 
-  pk: int = Field(description='Defines the primary key of the trigger')
+  pk: int = Field(description='Defines the primary key of the trigger', alias='id')
   name: str = Field(description='Defines the name of the trigger')
   code: str = Field(description='Defines the code of the trigger')
 
